@@ -1,11 +1,12 @@
 # functions that implement sample splitting for estimating partial effects and other purposes
 
 qgcomp.partials <- function(
-  fun = c("qgcomp.noboot", "qgcomp.cox.noboot", "qgcomp.zi.noboot"),
-  traindata=NULL,
-  validdata=NULL,
-  expnms=NULL,
-  ...
+    fun = c("qgcomp.noboot", "qgcomp.cox.noboot", "qgcomp.zi.noboot"),
+    traindata=NULL,
+    validdata=NULL,
+    expnms=NULL,
+    .fixbreaks=TRUE,
+    ...
 ){
   #' @title Partial effect sizes, confidence intervals, hypothesis tests
   #' @description Obtain effect estimates for "partial positive" and "partial
@@ -54,6 +55,7 @@ qgcomp.partials <- function(
   #' @param traindata Data frame with training data
   #' @param validdata Data frame with validation data
   #' @param expnms Exposure mixture of interest
+  #' @param .fixbreaks (logical) Use the same quantile cutpoints in the training and validation data (selected in the training data). As of version 2.8.11, the default is TRUE, whereas it was implicitly FALSE in prior verions. Setting to TRUE increases variance but greatly decreases bias in smaller samples.
   #' @param ... Arguments to \code{\link[qgcomp]{qgcomp.noboot}}, 
   #'    \code{\link[qgcomp]{qgcomp.cox.noboot}}, or 
   #'    \code{\link[qgcomp]{qgcomp.zi.noboot}}
@@ -138,14 +140,32 @@ qgcomp.partials <- function(
   #' splitres5
   #'                 
   #' }
+  # currently broken
   if(is.null(traindata) | is.null(validdata))
     stop("traindata and validdata must both be specified")
-  whichfun = fun[1]
-  train.fit = switch(whichfun, 
-                     qgcomp.noboot = qgcomp.noboot(data=traindata, expnms=expnms, ...),
-                     qgcomp.cox.noboot = qgcomp.cox.noboot(data=traindata, expnms=expnms, ...),
-                     qgcomp.zi.noboot = qgcomp.zi.noboot(data=traindata, expnms=expnms, ...)
-  )
+  #
+  traincall <- validcall <- match.call(expand.dots = TRUE)
+  droppers <- match(c("traindata", "validdata", ".fixbreaks", "fun"), names(traincall), 0L) #index (will need to add names here if more arguments are added)
+  traincall[["data"]] <- eval(traincall[["traindata"]], parent.frame())
+  validcall[["data"]] <- eval(validcall[["validdata"]], parent.frame())
+  traincall <- traincall[-c(droppers)]
+  validcall <- validcall[-c(droppers)]
+  hasbreaks = ifelse("breaks" %in% names(traincall), TRUE, FALSE)
+  if(hasbreaks && .fixbreaks)
+    .fixbreaks=FALSE
+  #
+  if(is.function(fun)){
+    traincall[[1L]] <- validcall[[1L]] <- fun
+  }else{
+    traincall[[1L]] <- validcall[[1L]] <- as.name(fun[1])
+  }
+  train.fit = eval(traincall, parent.frame())
+  #####
+  if(.fixbreaks){
+    validcall$breaks = train.fit$breaks
+    validcall$q = NULL
+  }
+  ######
   posnms = names(train.fit$pos.weights)
   negnms = names(train.fit$neg.weights)
   if(length(posnms)==1 && all(posnms==c("count", "zero"))){
@@ -156,19 +176,15 @@ qgcomp.partials <- function(
   res$negmix <- res$posmix <- "none"
   if(length(posnms)>0){
     res$posmix = posnms
-    res$pos.fit <- switch(whichfun, 
-                          qgcomp.noboot = qgcomp.noboot(data=validdata, expnms=posnms, ...),
-                          qgcomp.cox.noboot = qgcomp.cox.noboot(data=validdata, expnms=posnms, ...),
-                          qgcomp.zi.noboot = qgcomp.zi.noboot(data=validdata, expnms=posnms, ...)
-    )
+    vc = as.list(validcall)
+    vc$expnms = c(posnms)
+    res$pos.fit <- eval(as.call(vc), parent.frame())
   }
   if(length(negnms)>0){
     res$negmix = negnms
-    res$neg.fit <- switch(whichfun, 
-                          qgcomp.noboot = qgcomp.noboot(data=validdata, expnms=negnms, ...),
-                          qgcomp.cox.noboot = qgcomp.cox.noboot(data=validdata, expnms=negnms, ...),
-                          qgcomp.zi.noboot = qgcomp.zi.noboot(data=validdata, expnms=negnms, ...)
-    )
+    vc = as.list(validcall)
+    vc$expnms = c(negnms)
+    res$neg.fit <- eval(as.call(vc), parent.frame())
     
   }
   class(res) <- "qgcompmultifit"
@@ -177,6 +193,7 @@ qgcomp.partials <- function(
 
 
 
+
 print.qgcompmultifit <- function(x, ...){
   #' @export
   cat(paste0("\nVariables with positive effect sizes in training data: ", paste(x$posmix, collapse = ", ")))
